const guildNameRestrictions: genericValidation = {
	length: { min: 3, max: 100 },
	regex: /^[\p{L}\p{N} ._-]+$/u,
};

function isValidGuildName(rawName: string): validationResult {
	const name = rawName.trim().normalize("NFC");

	if (!name) return { valid: false, error: "Guild name is required" };

	if (name.length < guildNameRestrictions.length.min)
		return { valid: false, error: "Guild name is too short" };

	if (name.length > guildNameRestrictions.length.max)
		return { valid: false, error: "Guild name is too long" };

	if (!guildNameRestrictions.regex.test(name))
		return { valid: false, error: "Guild name contains invalid characters" };

	if (/^[._ -]|[._ -]$/.test(name))
		return {
			valid: false,
			error: "Guild name can't start or end with special characters",
		};

	return { valid: true, name };
}

export { guildNameRestrictions, isValidGuildName };
