const passwordRestrictions: genericValidation = {
	length: { min: 12, max: 64 },
	regex: /^(?=.*\p{Ll})(?=.*\p{Lu})(?=.*\d)(?=.*[^\w\s]).{12,64}$/u,
};

function isValidPassword(rawPassword: string): validationResult {
	if (!rawPassword) {
		return { valid: false, error: "Password is required" };
	}

	if (rawPassword.length < passwordRestrictions.length.min) {
		return {
			valid: false,
			error: `Password must be at least ${passwordRestrictions.length.min} characters`,
		};
	}

	if (rawPassword.length > passwordRestrictions.length.max) {
		return {
			valid: false,
			error: `Password must be at most ${passwordRestrictions.length.max} characters`,
		};
	}

	if (!passwordRestrictions.regex.test(rawPassword)) {
		return {
			valid: false,
			error:
				"Password must contain at least one uppercase, one lowercase, one digit, and one special character",
		};
	}

	return { valid: true };
}

export { passwordRestrictions, isValidPassword };
